@@ -25,7 +25,6 @@
 
 #include "net.h"
 #include "utils.h"
-#include "global.h"
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -77,7 +76,7 @@ typedef struct
     gboolean auto_max;
     gulong   max[SUM];
     gint     update_interval;
-    GdkColor color[SUM];
+    GdkRGBA  color[SUM];
     gchar    *label_text;
     gchar    *network_device;
     gchar    *old_network_device;
@@ -217,15 +216,15 @@ static gboolean update_monitors(t_global_monitor *global)
         switch (i) 
         {
             case IN:
-                PRINT_DBG("input: Max = %lu", global->monitor->net_max[i]);
+                DBG("input: Max = %lu", global->monitor->net_max[i]);
                 break;
                 
             case OUT:
-                PRINT_DBG("output: Max = %lu", global->monitor->net_max[i]);
+                DBG("output: Max = %lu", global->monitor->net_max[i]);
                 break;
                 
             case TOT:
-                PRINT_DBG("total: Max = %lu", global->monitor->net_max[i]);
+                DBG("total: Max = %lu", global->monitor->net_max[i]);
                 break;
         }
 #endif /* DEBUG */
@@ -285,7 +284,7 @@ static void run_update (t_global_monitor *global)
     if (global->monitor->options.update_interval > 0)
     {
         global->timeout_id =  g_timeout_add( global->monitor->options.update_interval, 
-            (GtkFunction)update_monitors, global);
+            (GSourceFunc)update_monitors, global);
     }
 }
 
@@ -296,7 +295,7 @@ static gboolean monitor_set_size(XfcePanelPlugin *plugin, int size, t_global_mon
     gint i;
     XfcePanelPluginMode mode = xfce_panel_plugin_get_mode (plugin);
 
-    PRINT_DBG("monitor_set_size");
+    DBG("monitor_set_size");
 
     if (mode == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
     {
@@ -331,7 +330,7 @@ static void monitor_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
 {
     gint i;
 
-    PRINT_DBG("monitor_set_mode");
+    DBG("monitor_set_mode");
 
     if (global->timeout_id)
     {
@@ -340,45 +339,49 @@ static void monitor_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
 
     if (mode == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
     {
-        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box), GTK_ORIENTATION_VERTICAL);
-        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box_bars), GTK_ORIENTATION_VERTICAL);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(global->box), GTK_ORIENTATION_VERTICAL);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(global->box_bars), GTK_ORIENTATION_VERTICAL);
         gtk_label_set_angle(GTK_LABEL(global->monitor->label), 0);
-        gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 0.5f, 1.0f);
-        gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.5f, 0.0f);
+        gtk_widget_set_halign(global->monitor->rcv_label,GTK_ALIGN_CENTER);
+        gtk_widget_set_valign(global->monitor->rcv_label,GTK_ALIGN_END);
+        gtk_widget_set_halign(global->monitor->sent_label,GTK_ALIGN_CENTER);
+        gtk_widget_set_valign(global->monitor->sent_label,GTK_ALIGN_START);
         gtk_label_set_angle(GTK_LABEL(global->monitor->rcv_label), 0);
         gtk_label_set_angle(GTK_LABEL(global->monitor->sent_label), 0);
         for (i = 0; i < SUM; i++)
-            gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(global->monitor->status[i]),
-                                             GTK_PROGRESS_LEFT_TO_RIGHT);
+            gtk_orientable_set_orientation(GTK_ORIENTABLE(global->monitor->status[i]),GTK_ORIENTATION_HORIZONTAL);
     }
     else if (mode == XFCE_PANEL_PLUGIN_MODE_VERTICAL)
     {
-        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box), GTK_ORIENTATION_VERTICAL);
-        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box_bars), GTK_ORIENTATION_VERTICAL);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(global->box), GTK_ORIENTATION_VERTICAL);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(global->box_bars), GTK_ORIENTATION_VERTICAL);
         gtk_label_set_angle(GTK_LABEL(global->monitor->label), 270);
-        gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 0.5f, 1.0f);
-        gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.5f, 0.0f);
+        gtk_widget_set_halign(global->monitor->rcv_label,GTK_ALIGN_CENTER);
+        gtk_widget_set_valign(global->monitor->rcv_label,GTK_ALIGN_END);
+        gtk_widget_set_halign(global->monitor->sent_label,GTK_ALIGN_CENTER);
+        gtk_widget_set_valign(global->monitor->sent_label,GTK_ALIGN_START);
         gtk_label_set_angle(GTK_LABEL(global->monitor->rcv_label), 270);
         gtk_label_set_angle(GTK_LABEL(global->monitor->sent_label), 270);
         for (i = 0; i < SUM; i++)
         {
-            gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(global->monitor->status[i]),
-                    GTK_PROGRESS_LEFT_TO_RIGHT);
+            gtk_orientable_set_orientation(GTK_ORIENTABLE(global->monitor->status[i]),GTK_ORIENTATION_HORIZONTAL);
         }
     }
     else /* mode == XFCE_PANEL_PLUGIN_MODE_HORIZONTAL */
     {
-        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box), GTK_ORIENTATION_HORIZONTAL);
-        xfce_hvbox_set_orientation(XFCE_HVBOX(global->box_bars), GTK_ORIENTATION_HORIZONTAL);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(global->box), GTK_ORIENTATION_HORIZONTAL);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(global->box_bars), GTK_ORIENTATION_HORIZONTAL);
         gtk_label_set_angle(GTK_LABEL(global->monitor->label), 0);
-        gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 1.0f, 0.5f);
-        gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.0f, 0.5f);
+        gtk_widget_set_halign(global->monitor->rcv_label,GTK_ALIGN_END);
+        gtk_widget_set_valign(global->monitor->rcv_label,GTK_ALIGN_CENTER);
+        gtk_widget_set_halign(global->monitor->rcv_label,GTK_ALIGN_START);
+        gtk_widget_set_valign(global->monitor->rcv_label,GTK_ALIGN_CENTER);
         gtk_label_set_angle(GTK_LABEL(global->monitor->rcv_label), 0);
         gtk_label_set_angle(GTK_LABEL(global->monitor->sent_label), 0);
         for (i = 0; i < SUM; i++)
         {
-            gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(global->monitor->status[i]),
-                    GTK_PROGRESS_BOTTOM_TO_TOP);
+            gtk_orientable_set_orientation(GTK_ORIENTABLE(global->monitor->status[i]),GTK_ORIENTATION_VERTICAL);
+            gtk_progress_bar_set_inverted(GTK_PROGRESS_BAR(global->monitor->status[i]),TRUE);
         }
     }
 
@@ -449,7 +452,7 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     
     for (i = 0; i < SUM; i++)
     {
-        gdk_color_parse(DEFAULT_COLOR[i], &global->monitor->options.color[i]);
+        gdk_rgba_parse(&global->monitor->options.color[i], DEFAULT_COLOR[i]);
 
         global->monitor->history[i][0] = 0;
         global->monitor->history[i][1] = 0;
@@ -462,7 +465,7 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     }
 
     /* Create widget containers */
-    global->box = xfce_hvbox_new(GTK_ORIENTATION_HORIZONTAL, FALSE, 0);
+    global->box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_container_set_border_width(GTK_CONTAINER(global->box), 2);
     gtk_widget_show(GTK_WIDGET(global->box));
 
@@ -484,7 +487,7 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     gtk_event_box_set_visible_window(GTK_EVENT_BOX(global->ebox_bars), FALSE);
     gtk_event_box_set_above_child(GTK_EVENT_BOX(global->ebox_bars), TRUE);
     gtk_widget_show(global->ebox_bars);
-    global->box_bars = xfce_hvbox_new(GTK_ORIENTATION_HORIZONTAL, FALSE, 0);
+    global->box_bars = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_widget_show(global->box_bars);
     for (i = 0; i < SUM; i++)
     {
@@ -506,6 +509,60 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     return global;
 }
 
+/* ---------------------------------------------------------------------------------------------- */
+static void set_label_csscolor(GtkWidget* label, GdkRGBA* color)
+{
+    GtkCssProvider *css_provider;
+    gchar * css;
+    if (color != NULL)
+    {
+#if GTK_CHECK_VERSION (3, 20, 0)
+        css = g_strdup_printf("label { color: %s; }",
+#else
+        css = g_strdup_printf(".label { color: %s; }",
+#endif
+                              gdk_rgba_to_string(color));
+    }
+    else
+    {
+#if GTK_CHECK_VERSION (3, 20, 0)
+        css = g_strdup_printf("label { color: inherit; }");
+#else
+        css = g_strdup_printf(".label { color: inherit; }");
+#endif
+    }
+    css_provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
+    g_free(css);
+
+    DBG("setting label css: %s", gtk_css_provider_to_string (css_provider));
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (label))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+}
+
+/* ---------------------------------------------------------------------------------------------- */
+static void set_progressbar_csscolor(GtkWidget* pbar, GdkRGBA* color)
+{
+    GtkCssProvider *css_provider;
+    gchar * css;
+#if GTK_CHECK_VERSION (3, 20, 0)
+    css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
+#else
+    css = g_strdup_printf(".progressbar { background-color: %s; background-image: none; }",
+#endif
+                          gdk_rgba_to_string(color));
+    DBG("setting pbar css to %s", css);
+    css_provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
+    g_free(css);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (pbar))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+}
 
 /* ---------------------------------------------------------------------------------------------- */
 static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
@@ -538,15 +595,28 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
 
     if (global->monitor->options.colorize_values)
     {
-        gtk_widget_modify_fg(global->monitor->rcv_label, GTK_STATE_NORMAL,
+#if GTK_CHECK_VERSION (3, 16, 0)
+        set_label_csscolor(global->monitor->rcv_label,
                              &global->monitor->options.color[IN]);
-        gtk_widget_modify_fg(global->monitor->sent_label, GTK_STATE_NORMAL,
+        set_label_csscolor(global->monitor->sent_label,
                              &global->monitor->options.color[OUT]);
+#else
+        gtk_widget_override_color(global->monitor->rcv_label, GTK_STATE_NORMAL,
+                             &global->monitor->options.color[IN]);
+        gtk_widget_override_color(global->monitor->sent_label, GTK_STATE_NORMAL,
+                             &global->monitor->options.color[OUT]);
+#endif
     }
     else
     {
-        gtk_widget_modify_fg(global->monitor->rcv_label, GTK_STATE_NORMAL, NULL);
-        gtk_widget_modify_fg(global->monitor->sent_label, GTK_STATE_NORMAL, NULL);
+        DBG("resetting label colors");
+#if GTK_CHECK_VERSION (3, 16, 0)
+        set_label_csscolor(global->monitor->rcv_label, NULL);
+        set_label_csscolor(global->monitor->sent_label, NULL);
+#else
+        gtk_widget_override_color(global->monitor->rcv_label, GTK_STATE_NORMAL, NULL);
+        gtk_widget_override_color(global->monitor->sent_label, GTK_STATE_NORMAL, NULL);
+#endif
     }
 
     /* Setup the progress bars */
@@ -562,15 +632,19 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
                 global->monitor->net_max[i] = global->monitor->options.max[i];
 
             /* Set bar colors */
-            gtk_widget_modify_bg(GTK_WIDGET(global->monitor->status[i]),
+#if GTK_CHECK_VERSION (3, 16, 0)
+            set_progressbar_csscolor(global->monitor->status[i], &global->monitor->options.color[i]);
+#else
+            gtk_widget_override_background_color(GTK_WIDGET(global->monitor->status[i]),
                                  GTK_STATE_PRELIGHT,
                                  &global->monitor->options.color[i]);
-            gtk_widget_modify_bg(GTK_WIDGET(global->monitor->status[i]),
+            gtk_widget_override_background_color(GTK_WIDGET(global->monitor->status[i]),
                                  GTK_STATE_SELECTED,
                                  &global->monitor->options.color[i]);
-            gtk_widget_modify_base(GTK_WIDGET(global->monitor->status[i]),
+            gtk_widget_override_color(GTK_WIDGET(global->monitor->status[i]),
                                    GTK_STATE_SELECTED,
                                    &global->monitor->options.color[i]);
+#endif
         }
     }
     else
@@ -627,13 +701,11 @@ static void monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *globa
 
     if ((value = xfce_rc_read_entry (rc, "Color_In", NULL)) != NULL)
     {
-        gdk_color_parse(value,
-                        &global->monitor->options.color[IN]);
+        gdk_rgba_parse(&global->monitor->options.color[IN], value);
     }
     if ((value = xfce_rc_read_entry (rc, "Color_Out", NULL)) != NULL)
     {
-        gdk_color_parse(value,
-                        &global->monitor->options.color[OUT]);
+        gdk_rgba_parse(&global->monitor->options.color[OUT], value);
     }
     if ((value = xfce_rc_read_entry (rc, "Text", NULL)) && *value)
     {
@@ -664,7 +736,7 @@ static void monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *globa
 
     global->monitor->options.values_as_bits = xfce_rc_read_bool_entry (rc, "Values_As_Bits", FALSE);
 
-    PRINT_DBG("monitor_read_config");
+    DBG("monitor_read_config");
     setup_monitor(global, TRUE);
 
     xfce_rc_close (rc);
@@ -692,17 +764,8 @@ static void monitor_write_config(XfcePanelPlugin *plugin, t_global_monitor *glob
     xfce_rc_write_bool_entry (rc, "Show_Bars", global->monitor->options.show_bars);
     xfce_rc_write_bool_entry (rc, "Colorize_Values", global->monitor->options.colorize_values);
 
-    g_snprintf(value, 8, "#%02X%02X%02X",
-               (guint)global->monitor->options.color[IN].red >> 8,
-               (guint)global->monitor->options.color[IN].green >> 8,
-               (guint)global->monitor->options.color[IN].blue >> 8);
-    xfce_rc_write_entry (rc, "Color_In", value);
-
-    g_snprintf(value, 8, "#%02X%02X%02X",
-               (guint)global->monitor->options.color[OUT].red >> 8,
-               (guint)global->monitor->options.color[OUT].green >> 8,
-               (guint)global->monitor->options.color[OUT].blue >> 8);
-    xfce_rc_write_entry (rc, "Color_Out", value);
+    xfce_rc_write_entry (rc, "Color_In", gdk_rgba_to_string(&global->monitor->options.color[IN]));
+    xfce_rc_write_entry (rc, "Color_Out", gdk_rgba_to_string(&global->monitor->options.color[OUT]));
 
     xfce_rc_write_entry (rc, "Text", global->monitor->options.label_text ?
                                      global->monitor->options.label_text : "");
@@ -759,7 +822,7 @@ static void monitor_apply_options(t_global_monitor *global)
             GTK_SPIN_BUTTON(global->monitor->update_spinner) ) * 1000 + 0.5);
     
     setup_monitor(global, FALSE);
-    PRINT_DBG("monitor_apply_options_cb");
+    DBG("monitor_apply_options_cb");
 }
 
 
@@ -775,7 +838,7 @@ static void label_changed(GtkWidget *button, t_global_monitor *global)
         g_strdup(gtk_entry_get_text(GTK_ENTRY(global->monitor->opt_entry)));
 
     setup_monitor(global, FALSE);
-    PRINT_DBG("label_changed");
+    DBG("label_changed");
 }
 
 
@@ -790,7 +853,7 @@ static void max_label_changed(GtkWidget *button, t_global_monitor *global)
     }
 
     setup_monitor(global, FALSE);
-    PRINT_DBG("max_label_changed");
+    DBG("max_label_changed");
 }
 
 
@@ -806,7 +869,7 @@ static void network_changed(GtkWidget *button, t_global_monitor *global)
         g_strdup(gtk_entry_get_text(GTK_ENTRY(global->monitor->net_entry)));
 
     setup_monitor(global, FALSE);
-    PRINT_DBG("network_changed");
+    DBG("network_changed");
 }
 
 
@@ -820,7 +883,7 @@ static void label_toggled(GtkWidget *check_button, t_global_monitor *global)
                              global->monitor->options.use_label);
 
     setup_monitor(global, FALSE);
-    PRINT_DBG("label_toggled");
+    DBG("label_toggled");
 }
 
 /* ---------------------------------------------------------------------------------------------- */
@@ -830,7 +893,7 @@ static void as_bits_toggled(GtkWidget *check_button, t_global_monitor *global)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(global->monitor->opt_as_bits),
                                  global->monitor->options.values_as_bits);
 
-    PRINT_DBG("label_toggled");
+    DBG("label_toggled");
 }
 
 /* ---------------------------------------------------------------------------------------------- */
@@ -846,7 +909,7 @@ static void present_data_combobox_changed(GtkWidget *combobox, t_global_monitor
                              global->monitor->options.show_values);
 
     setup_monitor(global, FALSE);
-    PRINT_DBG("present_data_combobox_changed");
+    DBG("present_data_combobox_changed");
 }
 
 /* ---------------------------------------------------------------------------------------------- */
@@ -868,7 +931,7 @@ static void max_label_toggled(GtkWidget *check_button, t_global_monitor *global)
         }
     }
     setup_monitor(global, FALSE);
-    PRINT_DBG("max_label_toggled");
+    DBG("max_label_toggled");
 
 }
 
@@ -880,60 +943,16 @@ static void colorize_values_toggled(GtkWidget *check_button, t_global_monitor *g
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(global->monitor->opt_colorize_values),
                                  global->monitor->options.colorize_values);
     setup_monitor(global, FALSE);
-    PRINT_DBG("colorize_values_toggled");
-}
-
-
-/* ---------------------------------------------------------------------------------------------- */
-static gboolean expose_event_cb(GtkWidget *widget, GdkEventExpose *event)
-{
-    if (widget->window)
-    {
-        GtkStyle *style;
-
-        style = gtk_widget_get_style(widget);
-
-        gdk_draw_rectangle(widget->window,
-                           style->bg_gc[GTK_STATE_NORMAL],
-                           TRUE,
-                           event->area.x, event->area.y,
-                           event->area.width, event->area.height);
-    }
-
-    return TRUE;
+    DBG("colorize_values_toggled");
 }
 
 
 /* ---------------------------------------------------------------------------------------------- */
 static void change_color(GtkWidget *button, t_global_monitor *global, gint type)
 {
-    GtkWidget *dialog;
-    GtkColorSelection *colorsel;
-    gint response;
-
-    dialog = gtk_color_selection_dialog_new(_("Select color"));
-    gtk_window_set_transient_for(GTK_WINDOW(dialog),
-                                 GTK_WINDOW(global->opt_dialog));
-    colorsel =
-        GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(dialog)->colorsel);
-    gtk_color_selection_set_previous_color(colorsel,
-                                           &global->monitor->options.color[type]);
-    gtk_color_selection_set_current_color(colorsel,
-                                          &global->monitor->options.color[type]);
-    gtk_color_selection_set_has_palette(colorsel, TRUE);
-
-    response = gtk_dialog_run(GTK_DIALOG(dialog));
-    if (response == GTK_RESPONSE_OK)
-    {
-        gtk_color_selection_get_current_color(colorsel,
-                                              &global->monitor->options.color[type]);
-        gtk_widget_modify_bg(global->monitor->opt_da[type],
-                             GTK_STATE_NORMAL,
-                             &global->monitor->options.color[type]);
-        setup_monitor(global, FALSE);
-    }
-    PRINT_DBG("change_color");
-    gtk_widget_destroy(dialog);
+    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(button), &global->monitor->options.color[type]);
+    setup_monitor(global, FALSE);
+    DBG("change_color(%d) with %s", type, gdk_rgba_to_string(&global->monitor->options.color[type]));
 }
 
 
@@ -972,7 +991,6 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     GtkBox           *update_hbox;
     GtkWidget        *update_label, *update_unit_label;
     GtkWidget        *color_label[SUM];
-    GtkWidget        *align;
     gint             present_data_active;
     GtkSizeGroup     *sg;
     gint             i;
@@ -989,8 +1007,8 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     xfce_panel_plugin_block_menu (plugin);
     
     dlg = xfce_titled_dialog_new_with_buttons (_("Network Monitor"), NULL,
-                                               GTK_DIALOG_NO_SEPARATOR,
-                                               GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+                                               GTK_DIALOG_DESTROY_WITH_PARENT,
+                                               "gtk-close", GTK_RESPONSE_OK,
                                                NULL);
     
     gtk_window_set_icon_name (GTK_WINDOW (dlg), "xfce4-settings");
@@ -999,21 +1017,21 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
 
     global->opt_dialog = dlg;
     
-    global_vbox = GTK_BOX (gtk_vbox_new(FALSE, BORDER));
+    global_vbox = GTK_BOX (gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER));
     gtk_container_set_border_width (GTK_CONTAINER (global_vbox), BORDER - 2);
     gtk_widget_show(GTK_WIDGET (global_vbox));
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), GTK_WIDGET (global_vbox), TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG(dlg))), GTK_WIDGET (global_vbox), TRUE, TRUE, 0);
     
     sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
     
-    vbox = GTK_BOX(gtk_vbox_new(FALSE, 5));
+    vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 5));
     gtk_widget_show(GTK_WIDGET(vbox));
 
-    global->monitor->opt_vbox = GTK_BOX(gtk_vbox_new(FALSE, 5));
+    global->monitor->opt_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 5));
     gtk_widget_show(GTK_WIDGET(global->monitor->opt_vbox));
 
     /* Displayed text */
-    global->monitor->opt_hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
+    global->monitor->opt_hbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5));
     gtk_widget_show(GTK_WIDGET(global->monitor->opt_hbox));
     
     global->monitor->opt_use_label =
@@ -1044,12 +1062,12 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
                              global->monitor->options.use_label);
 
     /* Network device */
-    net_hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
+    net_hbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5));
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                         GTK_WIDGET(net_hbox), FALSE, FALSE, 0);
 
     device_label = gtk_label_new_with_mnemonic(_("Network _device:"));
-    gtk_misc_set_alignment(GTK_MISC(device_label), 0, 0.5);
+    gtk_widget_set_valign(device_label,GTK_ALIGN_CENTER);
     gtk_widget_show(GTK_WIDGET(device_label));
     gtk_box_pack_start(GTK_BOX(net_hbox), GTK_WIDGET(device_label),
                        FALSE, FALSE, 0);
@@ -1071,12 +1089,12 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_widget_show_all(GTK_WIDGET(net_hbox));
     
     /* Update timevalue */
-    update_hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
+    update_hbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5));
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                         GTK_WIDGET(update_hbox), FALSE, FALSE, 0);
     
     update_label = gtk_label_new_with_mnemonic(_("Update _interval:"));
-    gtk_misc_set_alignment(GTK_MISC(update_label), 0, 0.5);
+    gtk_widget_set_valign(update_label, GTK_ALIGN_CENTER);
     gtk_box_pack_start(GTK_BOX(update_hbox), GTK_WIDGET(update_label), FALSE, FALSE, 0);
 
     global->monitor->update_spinner = gtk_spin_button_new_with_range (0.1, 10.0, 0.05);
@@ -1096,7 +1114,7 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_size_group_add_widget(sg, update_label);
     
     /* Show values as bits */
-    bits_hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
+    bits_hbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5));
     gtk_widget_show(GTK_WIDGET(bits_hbox));
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                        GTK_WIDGET(bits_hbox), FALSE, FALSE, 0);
@@ -1111,7 +1129,7 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
                                  global->monitor->options.values_as_bits);
 
     
-    sep1 = gtk_hseparator_new();
+    sep1 = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox), GTK_WIDGET(sep1), FALSE, FALSE, 0);
     gtk_widget_show(sep1);
     
@@ -1127,12 +1145,12 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     /* Input maximum */
     for( i = 0; i < SUM; i++)
     {
-        global->monitor->max_hbox[i] = GTK_BOX(gtk_hbox_new(FALSE, 5));
+	global->monitor->max_hbox[i] = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5));
         gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox), 
                     GTK_WIDGET(global->monitor->max_hbox[i]), FALSE, FALSE, 0);
         
         max_label[i] = gtk_label_new_with_mnemonic(_(maximum_text_label[i]));
-        gtk_misc_set_alignment(GTK_MISC(max_label[i]), 0, 0.5);
+        gtk_widget_set_valign(max_label[i], GTK_ALIGN_CENTER);
         gtk_widget_show(GTK_WIDGET(max_label[i]));
         gtk_box_pack_start(GTK_BOX(global->monitor->max_hbox[i]), GTK_WIDGET(max_label[i]), FALSE, FALSE, 0);
         
@@ -1165,28 +1183,28 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
 
     } 
     
-    sep2 = gtk_hseparator_new();
+    sep2 = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox), GTK_WIDGET(sep2), FALSE, FALSE, 0);
     gtk_widget_show(sep2);
     
     /* Show bars and values */
-    global->monitor->opt_present_data_hbox = GTK_WIDGET(gtk_hbox_new(FALSE, 5));
+    global->monitor->opt_present_data_hbox = GTK_WIDGET(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5));
     gtk_widget_show(global->monitor->opt_present_data_hbox);
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                        GTK_WIDGET(global->monitor->opt_present_data_hbox), FALSE, FALSE, 0);
 
     global->monitor->opt_present_data_label = gtk_label_new_with_mnemonic(_("_Present data as:"));
-    gtk_misc_set_alignment(GTK_MISC(global->monitor->opt_present_data_label), 0, 0.5);
+    gtk_widget_set_valign(global->monitor->opt_present_data_label, GTK_ALIGN_CENTER);
     gtk_widget_show(global->monitor->opt_present_data_label);
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_present_data_hbox),
                        global->monitor->opt_present_data_label, FALSE, FALSE, 0);
 
-    global->monitor->opt_present_data_combobox = gtk_combo_box_new_text();
+    global->monitor->opt_present_data_combobox = gtk_combo_box_text_new();
     gtk_label_set_mnemonic_widget(GTK_LABEL(global->monitor->opt_present_data_label),
                                   global->monitor->opt_present_data_combobox);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), _("Bars"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), _("Values"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), _("Bars and values"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(global->monitor->opt_present_data_combobox), _("Bars"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(global->monitor->opt_present_data_combobox), _("Values"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(global->monitor->opt_present_data_combobox), _("Bars and values"));
 
     if(global->monitor->options.show_values)
         if(global->monitor->options.show_bars)
@@ -1205,29 +1223,21 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     /* Color 1 */
     for (i = 0; i < SUM; i++)
     {
-        global->monitor->opt_color_hbox[i] = gtk_hbox_new(FALSE, 5);
+	global->monitor->opt_color_hbox[i] = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
         gtk_widget_show(GTK_WIDGET(global->monitor->opt_color_hbox[i]));
         gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                 GTK_WIDGET(global->monitor->opt_color_hbox[i]), FALSE, FALSE, 0);
 
         color_label[i] = gtk_label_new_with_mnemonic(_(color_text[i]));
-        gtk_misc_set_alignment(GTK_MISC(color_label[i]), 0, 0.5);
+        gtk_widget_set_valign(color_label[i], GTK_ALIGN_CENTER);
         gtk_widget_show(GTK_WIDGET(color_label[i]));
         gtk_box_pack_start(GTK_BOX(global->monitor->opt_color_hbox[i]), GTK_WIDGET(color_label[i]),
                 FALSE, FALSE, 0);
 
-        global->monitor->opt_button[i] = gtk_button_new();
+        global->monitor->opt_button[i] = gtk_color_button_new_with_rgba(&global->monitor->options.color[i]);
         gtk_label_set_mnemonic_widget(GTK_LABEL(color_label[i]),
                                       global->monitor->opt_button[i]);
-        global->monitor->opt_da[i] = gtk_drawing_area_new();
-        
-        gtk_widget_modify_bg(global->monitor->opt_da[i], GTK_STATE_NORMAL,
-                &global->monitor->options.color[i]);
-        gtk_widget_set_size_request(global->monitor->opt_da[i], 64, 12);
-        gtk_container_add(GTK_CONTAINER(global->monitor->opt_button[i]),
-                global->monitor->opt_da[i]);
         gtk_widget_show(GTK_WIDGET(global->monitor->opt_button[i]));
-        gtk_widget_show(GTK_WIDGET(global->monitor->opt_da[i]));
         gtk_box_pack_start(GTK_BOX(global->monitor->opt_color_hbox[i]),
                 GTK_WIDGET(global->monitor->opt_button[i]),
                 FALSE, FALSE, 0);
@@ -1249,10 +1259,8 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
                 GTK_WIDGET(global->monitor->opt_vbox),
                 FALSE, FALSE, 0);
     
-    align = gtk_alignment_new(0, 0, 0, 0);
-    gtk_widget_set_size_request(align, 5, 5);
-    gtk_widget_show(GTK_WIDGET(align));
-    gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(align), FALSE, FALSE, 0);
+    gtk_widget_set_halign(GTK_WIDGET(vbox), GTK_ALIGN_START);
+    gtk_widget_set_valign(GTK_WIDGET(vbox), GTK_ALIGN_START);
 
     gtk_box_pack_start( GTK_BOX(global_vbox), GTK_WIDGET(vbox), FALSE, FALSE, 0);
     
@@ -1260,13 +1268,9 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
             G_CALLBACK(max_label_toggled), global);
     g_signal_connect(GTK_WIDGET(global->monitor->opt_colorize_values), "toggled",
             G_CALLBACK(colorize_values_toggled), global);
-    g_signal_connect(GTK_WIDGET(global->monitor->opt_da[0]), "expose_event",
-            G_CALLBACK(expose_event_cb), NULL);
-    g_signal_connect(GTK_WIDGET(global->monitor->opt_da[1]), "expose_event",
-            G_CALLBACK(expose_event_cb), NULL);
-    g_signal_connect(GTK_WIDGET(global->monitor->opt_button[IN]), "clicked",
+    g_signal_connect(GTK_WIDGET(global->monitor->opt_button[IN]), "color-set",
             G_CALLBACK(change_color_in), global);
-    g_signal_connect(GTK_WIDGET(global->monitor->opt_button[OUT]), "clicked",
+    g_signal_connect(GTK_WIDGET(global->monitor->opt_button[OUT]), "color-set",
             G_CALLBACK(change_color_out), global);
     g_signal_connect(GTK_WIDGET(global->monitor->opt_use_label), "toggled",
             G_CALLBACK(label_toggled), global);
